from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x09\x00\x61\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x99\x08\x00\x00\x00\x00\x00\x18\xe0\xdb\xdf\xf1\x4f\x76\x26\xb7\x9d\x11\x20\x7e\x87\x38\x86\xd8\x00\x00\x00\x00\x00\x00\x00\x00\x36\x10\xee\x38\x41\xc9\xb1\xb8\x03\xca\x44\x80\x00\x58\x30\x1c\xff\xf9\x40\xea\x60\x8b\xc6\xd1\xf6\x9f\x49\xd2\x49\x43\x7d\xc7\xf9\xe7\x3d\x0c\x0d\xc1\xf0\xf5\xd7\x75\xb2\x0e\x48\x9d\xe7\xda\x4f\xb3\x20\xf3\x67\xf1\xcf\xb5\xe0\xf2\x22\xf5\x86\x07\x8e\x6c\xe6\x0a\x04\x64\xf3\x88\x42\x1f\xc7\x6f\xc2\x19\xa6\x5e\xd9\xe9\x37\x9e\x1a\x12\x52\xa3\x62\x24\xed\x86\x78\x2b\x8a\xe8\xf1\x39\xb9\x3e\xd4\x0d\x05\x02\x68\xc6\xaf\x4c\x59\xe9\xae\x13\x01\x5b\x05\x21\x41\x38\xbc\xf6\x69\x03\x16\xb8\xe2\x1e\x2c\xd1\x38\x66\x9c\xe0\x2a\x6c\xc6\x0b\x43\x69\x0d\x20\xee\x23\x77\x80\xa7\x3e\xc1\x20\x7c\x3e\xb5\x1b\x81\x3a\x14\x4f\x68\x3e\x98\x60\x80\xcc\x74\x81\xdb\xb3\x4d\xd3\x4c\xb2\xdd\x80\xd8\xbe\x92\xa9\x55\x0d\x6e\xff\xbc\x75\xc2\x48\xad\x78\xdd\xa8\xbf\xbe\x8e\x81\x13\x6f\xc3\x13\xde\x22\x61\xcb\xa0\xa3\xf9\x64\xd4\xc5\x32\xb9\x98\xfa\x06\x3c\x86\xb1\x7c\x45\xed\x7e\xb3\x5d\x24\xb7\x1d\xfa\xe4\xac\xe6\xc3\xf5\x7f\x57\x81\x45\x49\xe6\xe0\x26\x3a\x97\x23\x88\x7e\xac\x79\x4a\xdb\xbf\x28\xcd\xf7\xdf\x9a\x92\x71\x9a\x67\xd4\x59\xc6\x10\xcf\x40\x92\x0b\x65\x37\x63\x7f\x5b\x42\xf5\x85\xab\xb4\x36\x32\x16\xd8\x82\x8d\x5c\x1c\x2b\x00\x02\x08\x8c\x57\x3e\x82\xec\xc8\xcd\x90\xd8\x37\xc3\x25\xff\xf9\xca\x47\x61\xae\xc8\x90\xe2\x42\xd7\x58\xf2\x5b\x7c\x1f\xe9\x40\x09\xaa\x33\x07\x70\xe5\x5a\xc4\xf6\x29\xec\xde\x53\x94\x7a\xc4\xe1\x4d\x7e\x63\xda\x26\xf5\x8a\x81\xef\xf0\xb0\xae\x00\x5c\x95\xbe\x3d\xc7\x61\x80\x4a\x7b\x16\x37\x5c\xef\x61\xdd\x22\x24\xa0\x7f\xa8\x3f\x34\xf4\x17\x0f\xb4\xc5\xb1\x72\xd4\x17\xbd\x2f\xbf\x58\xae\xd6\x33\xd5\xed\x6b\x89\x12\xe8\xa0\xb6\xd7\x64\xd7\x84\x98\x7a\xf5\x4c\xa7\xa0\x04\x5c\xfb\x08\x72\xa2\x53\x57\x04\x8d\x14\x8b\x1d\xb5\xed\xc3\xe2\x1a\x7c\x76\xb0\xb8\x65\xb1\x56\x48\x55\x0f\x81\x7b\xeb\xa1\x7d\x28\x15\x3f\x1b\xbe\x7f\xe6\x65\x43\x7f\x51\xa3\xe8\xd2\x3a\x7d\xad\x0b\x5e\xfb\xd9\x0e\xa7\x88\xb4\x97\xa8\x2c\xc7\xac\xfe\x2e\x90\xec\xd7\xe1\xb6\x7f\x26\x1f\xcb\x3f\x79\x36\xb3\x87\x04\xce\x8b\x69\x30\x2a\x4c\x92\x59\x4e\x8e\x6b\x44\x4b\x13\x90\xd5\x9f\xc1\x5a\xde\x4e\x3a\x3e\xfc\x08\x44\xd7\x49\xd1\xf7\x65\xdb\xff\x44\x31\xa6\x51\xe1\x5f\xfd\xfa\x53\x8e\x59\x21\xa1\x5d\x17\x6c\x79\x0a\xa6\xb6\x10\x5b\x1a\xf4\xa6\xbf\xa2\x4d\x10\xea\x51\x1a\xa7\x6b\xcf\xea\x08\x87\x9b\x5b\x1a\xe0\xd7\xd8\xdc\x07\xe6\xb8\x28\x3a\x08\x95\x05\xad\x20\x8d\x46\x6d\xdc\xf2\x24\xf3\x71\xa3\x53\x50\x7f\xe1\x79\x29\x3c\xb2\x7c\x07\x24\xca\xfb\x3c\xc6\x8e\x44\xb2\x7c\x1e\x31\xe7\x8a\xd4\xdc\x2e\x8e\xe3\x78\xb7\xcc\x13\x19\x67\xc4\x21\x39\x19\xcf\xe3\x05\x19\x1e\xf4\xde\x70\x56\x5e\x0f\xf9\x78\xcf\xd9\xbf\xe0\xff\x05\x04\x9e\xf3\xa3\xa2\x6b\x4d\x2d\x29\xa8\x3e\xc8\xd7\xf1\x17\xe7\x70\xb0\xcb\x80\x1c\xfd\x73\x87\xcb\x09\x8f\xc2\xee\x75\x5b\x42\x55\xf2\xf3\xd0\x83\x10\x7d\xf0\xe6\x67\xea\x98\xd2\xee\xe7\xf5\xb2\x0b\x5d\xd3\x4a\x3b\xff\x9b\x9c\xe5\x0c\xb0\x32\xdc\x1d\x7c\x1d\xb5\xd7\xae\x57\x10\x3c\xdc\x31\x45\x30\xe2\x9a\x9d\x6d\x8c\x05\x86\xf4\x1c\x4b\x3d\x96\xfb\x03\xe0\xf3\x1f\x9c\x6a\x46\x24\x12\xe0\x5f\xf4\xa0\x10\x81\xf4\x65\x18\x06\xb7\xf4\x91\x48\x00\x91\x35\xd9\xbf\xc6\xd1\x3f\x72\xaa\x7d\xe2\xbb\x99\xf3\xee\x84\x5c\x42\x23\x1d\xca\xe3\x13\x7c\x10\x43\xe5\xae\x2c\x29\x99\x73\x81\x80\x40\x83\x71\xe0\xee\xf5\x41\x81\xfd\xca\xe6\xe7\x9b\x49\x10\xca\x05\xbe\x7c\x26\x5f\x3d\xef\x64\x17\x2c\xe8\xc7\x45\xcf\x21\x10\x34\x9f\x48\x9e\x90\xc3\x29\xb8\xdf\x72\x68\x44\x27\x58\x09\x05\x0d\xb1\x31\x3b\xbd\xf2\x2f\x74\x70\xb0\x95\x97\x59\x5a\xdc\x81\x8d\xf7\x8f\x1e\xdc\x78\xcc\x4f\xf1\x65\x95\xe4\x12\x11\x42\x85\xee\x57\xcc\x0f\x83\x05\xfe\x2a\x57\x53\x8f\xeb\x38\xcc\xf7\xa4\x11\xb6\x08\xb1\x7d\x4e\x03\xba\xa3\xe0\x40\x8d\x90\xd8\xcb\x98\x23\xfe\x44\xda\xde\x2a\xd3\x20\x87\x8c\xc1\xb8\xed\x45\x14\x11\x70\xf9\x7c\xb2\x2c\x0d\xb9\x81\xb1\xe8\xfb\xb2\x87\x2b\x2a\xf3\xaa\x84\x23\xc3\xb1\x6d\x13\x7c\x25\x28\x5d\x47\xf0\xa7\x92\xbf\x39\xa9\x1b\xf8\xd1\xd9\x2d\x79\x4d\xd9\x4f\xd8\x28\x07\x68\xc5\xae\x84\xb4\x01\x91\x9c\x4d\xfc\xe5\xa5\x8e\x89\xd4\x7a\x9f\xb9\x78\x6c\x8d\x63\x74\x46\x3c\x98\x31\xe4\x7b\xa4\xb3\x77\xbd\x2f\x9f\x41\x86\x43\xba\x10\xa8\x80\xfd\xcd\xad\x62\x77\xba\x4e\x0f\x4b\x0d\xe7\x5b\x3d\xf8\x5a\x57\xc8\x68\x0b\x08\x27\x4c\x82\x1d\xef\x9f\xaa\x79\x10\xa2\xe6\x63\x28\xaf\x13\x72\x4c\xf5\x69\x40\xcc\x58\x6e\xc5\x23\x27\x53\x6d\x7c\xa1\xa2\x23\xf9\x96\xee\x92\xc1\x3f\x16\xde\xd6\x9b\x57\x9c\x40\xc7\x45\x52\x25\xd4\x30\x33\xc9\x77\x12\xd4\x58\x78\xb9\x3a\x58\x58\x63\x5d\x9c\xa8\x99\x99\x35\x75\x0f\x72\xf4\xde\x7a\xe7\xda\x33\xf0\xde\x44\x14\xdf\x07\xac\xa6\xa0\x64\x46\xc1\xd5\xb2\xae\xd9\xed\xe2\x24\x4d\x6a\xb6\x41\xc4\x10\x7c\x0a\xfe\xeb\xc2\x8f\x6b\x59\x9b\x03\x8d\x06\x68\xd9\x58\x18\x61\xdd\x02\x7a\x7a\x88\x5c\x4c\x45\x6c\x00\x3a\xe8\x79\x2a\xde\x9f\x1e\x9e\x26\xc4\x90\xbe\x16\xd0\xbc\xe7\x2d\x3b\x55\x87\xde\x4f\xdb\xf4\x12\x50\xd4\x5a\xe2\x5c\x25\xa9\xa0\x6b\x88\x8c\x69\xac\x8e\x45\x56\x7d\xca\x63\x41\x23\xd1\xfa\x09\x74\xdd\x17\x8e\xa4\xde\x6e\x9f\x28\x5c\xc9\xf6\x56\x8d\x28\xa0\xce\xf5\x5f\x2c\x04\x75\x34\xc0\x71\x6c\x53\x1e\x3e\x25\x0a\xd9\x0f\x8a\xd6\xf1\xc2\x32\xe0\x81\x86\xeb\x7d\x2f\xc2\x90\x63\xe6\xfa\x01\xb9\x92\x57\xfd\x92\xc4\x03\x73\xab\x16\x5a\xf5\x50\x29\x69\x20\x42\x41\x86\x4d\x88\x73\x1b\xc4\xb1\x60\x1e\xda\xa1\x07\x1c\x3a\xf7\xa0\xd6\xdb\x7f\x3e\xdb\xec\xcd\x18\xc5\x50\xd1\x1d\x16\x0c\x38\x0c\x0e\xcf\xff\x67\x04\x74\x19\x31\xe4\x93\xad\x05\x57\x79\xe3\x87\x19\xe0\x2a\xac\x48\x9a\x54\x65\x79\x94\xf9\x3a\xfb\x93\x39\xfa\x1e\xbf\x48\xef\xcf\x58\xbf\xc1\x05\x25\x7a\x96\x7c\x9d\xe0\x06\x33\x38\xe7\x52\x94\x9b\x85\x0a\x80\x04\xad\x73\x85\x9c\xac\xa7\xd7\x35\x0e\x30\x7a\xd1\x1a\xbe\x5a\x45\x80\x9b\xee\x2b\x88\x0e\x13\x61\x29\x5f\xc6\x39\xf8\x85\xaa\xb4\xb7\xab\xec\x9f\xe6\x4c\x50\x9e\x22\x18\xa0\xdb\x5f\xaa\x19\x56\x08\xb5\x68\x64\xce\xaf\x52\x89\x76\x5b\x96\x57\x78\x74\xae\x21\x66\xd4\x9b\xb6\x47\x0c\x75\xbe\x96\x66\x5d\x20\x15\x27\x7b\xcb\xb1\x38\x48\x23\xf2\x47\x35\xb2\x58\x92\x60\x26\x05\x4e\x68\x26\x6c\xcc\x39\x83\x45\xf4\xbf\x46\xc3\x89\x8a\xc5\xf8\xda\xad\x6e\xad\xbd\x8e\x60\xe3\xa9\x9b\xe1\x9c\x89\xcc\xf3\x52\x7d\xad\x96\x47\x43\xee\x18\x98\x0b\x48\x36\xe3\xd2\x5a\x66\xea\xd7\x1c\x54\x2a\x71\x08\x2f\xb3\x3b\xf9\x74\x45\x6d\xec\x71\x48\xfb\x2c\x21\x00\x7a\x24\xd9\xcb\x96\x5f\x39\xe5\x73\xc3\x7f\xc0\xe0\xda\x48\xfb\x5b\xa8\x59\xd4\x9b\x28\xf9\x23\xf5\xf6\xce\x0f\x75\x00\xb5\x8d\xe2\x4e\x66\x60\xc1\x4e\xa7\xa3\x39\x96\x86\xaa\x73\x9a\x5d\xac\x53\x01\x5d\x89\x61\x22\xa9\xf2\xf9\x58\x58\xad\x77\x93\xcf\x7d\xc9\xdd\x2b\x4e\x9b\x89\x87\xd5\x9c\x29\xdc\x27\x03\xd0\x1a\x39\x8c\x2c\x7f\x50\x31\x3f\x33\x51\xdd\x38\xb9\x6a\x2f\x38\x70\xa8\x91\x4f\xae\xc3\x79\x75\xb3\x48\x6f\xc1\xd3\xc5\x4f\xe9\x99\xa8\x6e\xa7\xdd\x73\xed\x1f\xd8\x66\xd7\x0b\x23\x46\xbb\xce\xf7\x0f\x5c\x32\xec\x3a\x61\xb7\xa1\x13\xd8\x42\x54\x11\x90\xdc\x2d\x23\x42\x9f\xa7\xb6\xe3\xfe\xf0\x67\x3f\x06\xcf\x92\x38\x59\x9b\x94\x84\x78\xe2\x20\xe3\x02\x41\x74\xf2\xcc\x48\x4e\xa7\x11\x6a\xc6\x28\xd6\xc9\x76\x13\xca\x4f\xf0\x64\x90\xd0\xce\x56\x71\xa2\xab\xe8\x65\x95\xb3\x91\xd4\x39\x3d\x41\x06\xe3\x98\xa2\x8b\xe5\x2f\x43\x2a\x38\xf1\x80\xdd\x4f\x2a\x96\x8f\xed\x1c\x67\x55\x9c\x79\xdb\x70\xfc\x76\xc4\xaf\xa6\xd8\x2e\xb5\x38\xc9\x90\xda\x34\xac\xa8\x62\xc6\x24\x33\xa2\xbc\x19\x88\x3b\xb1\x77\x8f\xa1\x27\x2c\x32\x93\x15\x3f\x8b\x8c\x06\xcd\xd1\x68\xfe\x3b\xd2\x9d\x01\x5d\x71\xfb\x0f\x95\xe4\x83\xaa\xc8\x82\x96\x9e\xa7\x8a\xa7\x0e\x40\x9c\xac\x95\x72\x3f\xb8\xd9\xd4\x0b\x21\x0b\x5f\x82\x4d\xab\x58\x71\xbf\x12\x85\x89\x68\x81\xad\x5f\x6c\xa7\x54\x86\x5e\x95\x97\xb1\xe0\xcf\xa0\x0f\x90\x46\x82\x9d\xab\x55\xb0\x77\xa8\x03\x38\x62\xae\xf6\xdd\xa6\x07\x00\x27\x59\x53\xb6\x4c\x2e\x5f\xdd\x10\xfb\xf4\x2e\x16\x58\x7a\xae\xc9\x2f\xe5\x6c\xc9\x3a\x69\x24\x35\xb6\x74\x30\x98\x73\x0e\x6b\x9d\xe3\x37\x77\x0e\x77\x4f\x1f\x46\xb6\x8f\x4b\x7c\xf2\x35\x97\x77\xe9\x49\x78\x10\xca\xda\xe3\x61\x10\xd2\x49\x2d\x32\x79\x95\x33\x85\x5a\xb3\x09\x17\x68\xa6\x09\x4b\xc8\xda\x6b\xda\x5b\x25\xdb\xb1\x1f\x8f\xbe\x31\x87\x10\xf3\x89\xf3\x17\x93\xcb\x51\x11\x9c\x5e\x1d\x24\x1d\xa3\xc5\x40\x75\x38\x00\x9b\xac\xcd\x58\x0e\xec\xc8\x03\x6b\xed\xb3\x11\x17\xb3\x16\x43\xb3\xef\xb5\x25\x48\x73\x4d\x53\x7d\x26\x6b\xef\x7b\x76\xd0\x91\x85\x8f\x6b\xd9\x73\x58\x01\x57\x47\x15\x90\x98\x55\xac\xf2\xf3\x2f\xcc\x9f\x73\x62\x25\xe3\xed\x45\xc5\x35\xad\x2a\x26\x14\xec\xbb\xa7\xac\xd1\x39\x25\xb7\xec\x85\xe1\x97\x16\xde\xdc\xe6\x67\xd8\x03\x72\xe5\x3d\xd1\x50\x67\xb1\xd1\x5f\xc1\x43\x10\xa7\xc8\xab\x2c\xfd\x49\x35\x92\xdf\x70\xba\x21\xa4\xa5\xdf\xd9\xcc\xac\x1c\x60\x78\x98\x45\x1f\xeb\x19\xdc\xd7\x80\xe6\x18\x5f\x59\xac\xa7\xa3\xb4\x3d\x09\xde\xc0\x2f\xc2\x65\x33\x9e\x01\x53\x93\xbb\x54\x5b\x1d\xf9\xeb\xec\xd0\x04\x98\x08\xaa\x0f\x0e\x43\x39\x53\x12\x90\x27\x10\x78\x0b\x2b\xdc\x72\x9d\x55\xbc\x89\x5d\x0c\x75\x67\x55\x26\x91\xb2\x65\xbe\x5d\xda\x23\x1c\x85\xf7\xa9\xfe\x0a\xe1\x10\x06\xf1\x89\x8a\x4e\x7f\xef\x46\x66\xcd\x97\xf8\x69\xb2\x75\xe6\x9b\xdb\x82\x92\xf2\xc9\xdb\xa4\x09\x52\x8f\x8c\xd0\xcd\x3c\xf2\xb2\x56\xd5\xde\x7e\xe8\xde\x4e\x8d\x97\xc1', 2)

# cleanup
del pyarmor_runtime

